summary refs log tree commit diff
path: root/scripts-dev
diff options
context:
space:
mode:
authorPatrick Cloke <clokep@users.noreply.github.com>2022-12-21 13:05:21 -0500
committerGitHub <noreply@github.com>2022-12-21 13:05:21 -0500
commit7010a3d0151b88b3a9a7451201eaf9c5bbe48d64 (patch)
treeb5214edd8759b4334451d10a36fe7835c58fc76b /scripts-dev
parentBump minimum PyYAML to 3.13. (#14720) (diff)
downloadsynapse-7010a3d0151b88b3a9a7451201eaf9c5bbe48d64.tar.xz
Switch to ruff instead of flake8. (#14633)
ruff is a flake8-compatible Python linter written in Rust.
It supports the flake8 plugins that we use and is significantly
faster in testing.
Diffstat (limited to 'scripts-dev')
-rwxr-xr-xscripts-dev/lint.sh5
1 files changed, 2 insertions, 3 deletions
diff --git a/scripts-dev/lint.sh b/scripts-dev/lint.sh
index bf900645b1..f6b81013c3 100755
--- a/scripts-dev/lint.sh
+++ b/scripts-dev/lint.sh
@@ -1,9 +1,8 @@
 #!/usr/bin/env bash
 #
 # Runs linting scripts over the local Synapse checkout
-# isort - sorts import statements
 # black - opinionated code formatter
 # flake8 - lints and finds mistakes
 
 set -e
 
@@ -105,6 +104,6 @@ set -x
 isort "${files[@]}"
 python3 -m black "${files[@]}"
 ./scripts-dev/config-lint.sh
-flake8 "${files[@]}"
+ruff "${files[@]}"
 ./scripts-dev/check_pydantic_models.py lint
 mypy
@@ -1,9 +1,8 @@
 # black - opinionated code formatter
-# flake8 - lints and finds mistakes
+# ruff - lints and finds mistakes
 
 set -e